@@ -3,49 +3,12 @@ package ColorThemeBase::Static;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-07'; # DATE
 our $DIST = 'ColorThemeBase-Static'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict 'subs', 'vars';
 #use warnings;
 
-sub new {
-    my $class = shift;
-
-    # check that %THEME exists
-    my $theme_hash = \%{"$class\::THEME"};
-    unless (defined $theme_hash->{v}) {
-        die "Class $class does not define \%THEME with 'v' key";
-    }
-    unless ($theme_hash->{v} == 2) {
-        die "\%$class\::THEME's v is $theme_hash->{v}, I only support v=2";
-    }
-
-    # check for known and required arguments
-    my %args = @_;
-    {
-        my $args_spec = $theme_hash->{args};
-        last unless $args_spec;
-        for my $arg_name (keys %$args_spec) {
-            die "Unknown argument '$arg_name'" unless $args_spec->{$arg_name};
-        }
-        for my $arg_name (keys %$args_spec) {
-            die "Missing required argument '$arg_name'"
-                if $args_spec->{$arg_name}{req} && !exists($args{$arg_name});
-            # apply default
-            $args{$arg_name} = $args_spec->{$arg_name}{default}
-                if !defined($args{$arg_name}) &&
-                exists $args_spec->{$arg_name}{default};
-        }
-    }
-
-    bless {
-        args => \%args,
-
-        # we store this because applying roles to object will rebless the object
-        # into some other package.
-        orig_class => $class,
-    }, $class;
-}
+use parent 'ColorThemeBase::Constructor';
 
 sub get_color_list {
     my $self = shift;
@@ -89,7 +52,7 @@ ColorThemeBase::Static - Base class for color theme modules with static list of
 
 =head1 VERSION
 
-This document describes version 0.001 of ColorThemeBase::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-07.
+This document describes version 0.002 of ColorThemeBase::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-07.
 
 =head1 DESCRIPTION
 
